@@ -83,7 +83,7 @@ class MetTimeseries(object):
                     boxcar(window_size), boundary='extend', 
                     preserve_nan=True)
 
-            if(self.data_trend is None):
+            if(i == 0):
                 self.data_trend = local_data_trend
             else:
                 self.data_trend = np.append(self.data_trend,
